@@ -53,8 +53,8 @@ static int do_recv(int sock, char *buffer, int size) {
 		return -1;
 	while (len > 0 && (buffer[len - 1] == '\r' || buffer[len - 1] == '\n'))
 		len--;
-	if (len == size)
-		buffer[len - 1] = '\0';
+	/* properly end the string and prevent buffer overflows */
+	buffer[len < size ? len : len - 1] = '\0';
 
 	if (v_opt)
 		log("<-- [%s]", buffer);
@@ -144,6 +144,9 @@ static void list_folder(int sock, char *base, char *path)
 			log("stat %s: %s", fpath, strerror(errno));
 			continue;
 		}
+		if (!a_opt && namelist[i]->d_name[0] == '.')
+			continue;
+
 		if (S_ISDIR(st.st_mode)) {
 			if ((strcmp(namelist[i]->d_name, ".") == 0) ||
 			    (strcmp(namelist[i]->d_name, "..") == 0))
@@ -161,6 +164,9 @@ static void list_folder(int sock, char *base, char *path)
 			log("stat %s: %s", fpath, strerror(errno));
 			continue;
 		}
+		if (!a_opt && namelist[i]->d_name[0] == '.')
+			continue;
+
 		if (! S_ISDIR(st.st_mode)) {
 			snprintf(line, PATH_MAX, "%s|%s|0|\n",
 				namelist[i]->d_name, fpath);
@@ -220,7 +226,7 @@ static void handle_size(int sock, char *request)
       		return;
 	}
 
- 	snprintf(response, sizeof(response), "%015lld", st.st_size);
+ 	snprintf(response, sizeof(response), "%015lld", (long long)st.st_size);
   	do_send(sock, response, 15);
 }
 
@@ -232,7 +238,11 @@ static void handle_get(int sock, char *request, int fd)
 	size_t chunk;
 	int lfd = -1;
 	long o, c;
+#ifdef Linux
 	size_t sent;
+#else /* FreeBSD */
+	off_t sent;
+#endif
 
 	p1 = index(request, '/');
 	p2 = index(request, '|');
@@ -283,7 +293,7 @@ static void handle_get(int sock, char *request, int fd)
 #ifdef Linux
 	if ((sent = sendfile(sock, fd, &offset, chunk)) < 0) {
 #else /* FreeBSD */
-	if ((sent = sendfile(fd, sock, offset, chunk, NULL, NULL, 0)) < 0) {
+	if (sendfile(fd, sock, offset, chunk, NULL, &sent, 0) < 0) {
 #endif
 		log("sendfile: %s", strerror(errno));
 		if (lfd != -1)
