@@ -42,7 +42,7 @@
 #include "kissd.h"
 
 char *c_opt = NULL;
-int d_opt = 0, k_opt = 0, v_opt = 0;
+int a_opt = 0, d_opt = 0, k_opt = 0, v_opt = 0;
 
 char audiopath[PATH_MAX] = "\0";
 char videopath[PATH_MAX] = "\0";
@@ -330,6 +330,7 @@ static void usage(const char *program)
 		"KiSS PC-Link daemon " KISSD_VERSION "\n\n"
 		"Usage: %s [OPTION]\n"
 		"\nOptions:\n"
+		"\t-a, --all\t\tdo not hide entries starting with .\n"
 		"\t-c, --config=FILE\tpath to the configuration file\n"
 		"\t-d, --daemon\t\tfork into background and log using syslog\n"
 		"\t-h, --help\t\tprint this on-line help\n"
@@ -342,6 +343,7 @@ int main(int argc, char *argv[])
 {
 	int c;
 	static struct option long_options[] = {
+		{ "all", 0, NULL, 'a' },
 		{ "config", 1, NULL, 'c' },
 		{ "daemon", 0, NULL, 'd' },
 		{ "help", 0, NULL, 'h' },
@@ -351,11 +353,14 @@ int main(int argc, char *argv[])
 	};
 
 	while (1) {
-		c = getopt_long(argc, argv, "c:dhkv", long_options, NULL);
+		c = getopt_long(argc, argv, "ac:dhkv", long_options, NULL);
 		if (c == -1)
 			break;
 
 		switch (c) {
+		case 'a':
+			a_opt = 1;
+			break;
 		case 'c':
 			c_opt = optarg;
 			break;
