@@ -24,14 +24,14 @@
 
 #include <syslog.h>
 
-extern int d_opt, k_opt, v_opt;
+extern int a_opt, d_opt, k_opt, v_opt;
 
 extern char audiopath[];
 extern char videopath[];
 extern char picturepath[];
 extern char kmlurl[];
 
-#define KISSD_VERSION "version 0.8, Aug 26, 2005"
+#define KISSD_VERSION "version 0.9, Sep 27, 2005"
 
 void handle_request(int sock);
 void handle_kmlrequest(int sock);
